@@ -51,11 +51,11 @@ SMS::OVH - Send SMS using OVH API (https://api.ovh.com/)
 
 =head1 VERSION
 
-Version 0.003001
+Version 0.01
 
 =cut
 
-our $VERSION = '0.003001';
+our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
@@ -64,13 +64,9 @@ You'll need the OvhApi.pm module provided by OVH at:
 
 https://eu.api.ovh.com/wrappers/OvhApi-perl-1.1.zip
 
-OvhApi is not a CPAN modeula (yet), so you'll need to have it installed before install this module.
+    use Ovh::SMS;
 
-This module also depends on Moose (https://metacpan.org/pod/Moose)
-
-    use SMS::OVH;
-
-    my $sms = SMS::OVH->new(
+    my $sms = Ovh::SMS->new(
         app_key => 'your-key',
         app_secret => 'your-secret',
         cons_key => 'your-cons-key',
@@ -86,9 +82,6 @@ This module also depends on Moose (https://metacpan.org/pod/Moose)
 
 =head2 send
 
-This is the only method. It just tries to complete the API request.
-It takes no arguments, just uses the parameters set when the instance is created.
-
 =cut
 
 sub send {
@@ -117,6 +110,9 @@ Please report any bugs or feature requests to C<bug-sms-ovh at rt.cpan.org>, or
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=SMS-OVH>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
+
+
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -146,11 +142,13 @@ L<http://search.cpan.org/dist/SMS-OVH/>
 
 =back
 
+
+=head1 ACKNOWLEDGEMENTS
+
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2015 Paco Esteban.
-                  and
-               Powerspace Advertising SL <http://powerspace.com/>
 
 This program is distributed under the (Revised) BSD License:
 L<http://www.opensource.org/licenses/BSD-3-Clause>
